==> zio-aws-cognitosync_2.12-5.17.121.3-sources.jar: zio/aws/cognitosync/model/ListDatasetsResponse.scala <==
package zio.aws.cognitosync.model
import zio.aws.cognitosync.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListDatasetsResponse(
    datasets: Option[Iterable[zio.aws.cognitosync.model.Dataset]] = None,
    count: Option[Integer] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse = {
    import ListDatasetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
      .builder()
      .optionallyWith(
        datasets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.datasets)
      .optionallyWith(
        count.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.count)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.cognitosync.model.ListDatasetsResponse.ReadOnly =
    zio.aws.cognitosync.model.ListDatasetsResponse.wrap(buildAwsValue())
}
object ListDatasetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitosync.model.ListDatasetsResponse =
      zio.aws.cognitosync.model.ListDatasetsResponse(
        datasets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        count.map(value => value),
        nextToken.map(value => value)
      )
    def datasets: Option[List[zio.aws.cognitosync.model.Dataset.ReadOnly]]
    def count: Option[Integer]
    def nextToken: Option[String]
    def getDatasets
        : ZIO[Any, AwsError, List[zio.aws.cognitosync.model.Dataset.ReadOnly]] =
      AwsError.unwrapOptionField("datasets", datasets)
    def getCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("count", count)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
  ) extends zio.aws.cognitosync.model.ListDatasetsResponse.ReadOnly {
    override val datasets
        : Option[List[zio.aws.cognitosync.model.Dataset.ReadOnly]] = scala
      .Option(impl.datasets())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitosync.model.Dataset.wrap(item)
        }.toList
      )
    override val count: Option[Integer] = scala
      .Option(impl.count())
      .map(value => zio.aws.cognitosync.model.primitives.Integer(value))
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
  ): zio.aws.cognitosync.model.ListDatasetsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cognitosync_2.12-5.17.157.1-sources.jar: zio/aws/cognitosync/model/ListDatasetsResponse.scala <==
package zio.aws.cognitosync.model
import zio.aws.cognitosync.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListDatasetsResponse(
    datasets: Option[Iterable[zio.aws.cognitosync.model.Dataset]] = None,
    count: Option[Integer] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse = {
    import ListDatasetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
      .builder()
      .optionallyWith(
        datasets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.datasets)
      .optionallyWith(count.map(value => value: java.lang.Integer))(_.count)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.cognitosync.model.ListDatasetsResponse.ReadOnly =
    zio.aws.cognitosync.model.ListDatasetsResponse.wrap(buildAwsValue())
}
object ListDatasetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitosync.model.ListDatasetsResponse =
      zio.aws.cognitosync.model.ListDatasetsResponse(
        datasets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        count.map(value => value),
        nextToken.map(value => value)
      )
    def datasets: Option[List[zio.aws.cognitosync.model.Dataset.ReadOnly]]
    def count: Option[Integer]
    def nextToken: Option[String]
    def getDatasets
        : ZIO[Any, AwsError, List[zio.aws.cognitosync.model.Dataset.ReadOnly]] =
      AwsError.unwrapOptionField("datasets", datasets)
    def getCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("count", count)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
  ) extends zio.aws.cognitosync.model.ListDatasetsResponse.ReadOnly {
    override val datasets
        : Option[List[zio.aws.cognitosync.model.Dataset.ReadOnly]] = scala
      .Option(impl.datasets())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cognitosync.model.Dataset.wrap(item)
        }.toList
      )
    override val count: Option[Integer] =
      scala.Option(impl.count()).map(value => value: Integer)
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitosync.model.ListDatasetsResponse
  ): zio.aws.cognitosync.model.ListDatasetsResponse.ReadOnly = new Wrapper(impl)
}
